Fix typos. (#595)

diff --git a/mobly/base_test.py b/mobly/base_test.py
index 3a7f19f..7807a51 100644
--- a/mobly/base_test.py
+++ b/mobly/base_test.py
@@ -45,7 +45,7 @@
 
 
 class Error(Exception):
-    """Raised for exceptions that occured in BaseTestClass."""
+    """Raised for exceptions that occurred in BaseTestClass."""
 
 
 class BaseTestClass(object):
diff --git a/mobly/controllers/monsoon.py b/mobly/controllers/monsoon.py
index a5949e3..2f81ed6 100644
--- a/mobly/controllers/monsoon.py
+++ b/mobly/controllers/monsoon.py
@@ -346,8 +346,7 @@
             seq, _type, x, y = struct.unpack("BBBB", _bytes[:4])
             data = [
                 struct.unpack(">hhhh", _bytes[x:x + 8])
-                for x in range(4,
-                               len(_bytes) - 8, 8)
+                for x in range(4, len(_bytes) - 8, 8)
             ]
 
             if self._last_seq and seq & 0xF != (self._last_seq + 1) & 0xF:
@@ -703,7 +702,7 @@
         self.mon.SetMaxCurrent(cur)
 
     def set_max_init_current(self, cur):
-        """Sets the max power-up/inital current.
+        """Sets the max power-up/initial current.
 
         Args:
             cur: The max initial current allowed in mA.
diff --git a/mobly/signals.py b/mobly/signals.py
index f480f6e..1d0095d 100644
--- a/mobly/signals.py
+++ b/mobly/signals.py
@@ -77,4 +77,4 @@
 
 
 class ControllerError(Exception):
-    """Raised when an error occured in controller classes."""
+    """Raised when an error occurred in controller classes."""
diff --git a/mobly/utils.py b/mobly/utils.py
index 08b1977..f1b013c 100644
--- a/mobly/utils.py
+++ b/mobly/utils.py
@@ -462,7 +462,7 @@
 
     Propagates the exception raised by the subprocess.wait(.) function.
     The subprocess.TimeoutExpired exception is raised if the process timed-out
-    rather then terminating.
+    rather than terminating.
 
     If no exception is raised: the subprocess terminated on its own. No need
     to call stop_standing_subprocess() to kill it.
diff --git a/tests/mobly/base_test_test.py b/tests/mobly/base_test_test.py
index abe3a13..2cb3bb0 100755
--- a/tests/mobly/base_test_test.py
+++ b/tests/mobly/base_test_test.py
@@ -778,7 +778,7 @@
         self.assertIsNone(actual_record.extras)
 
     def test_promote_extra_errors_to_termination_signal(self):
-        """If no termination singal is specified, use the first extra error as
+        """If no termination signal is specified, use the first extra error as
         the termination signal.
         """
         expected_extra_error = Exception('teardown_test Exception.')
diff --git a/tests/mobly/controllers/android_device_lib/jsonrpc_client_base_test.py b/tests/mobly/controllers/android_device_lib/jsonrpc_client_base_test.py
index a696d88..7be4190 100755
--- a/tests/mobly/controllers/android_device_lib/jsonrpc_client_base_test.py
+++ b/tests/mobly/controllers/android_device_lib/jsonrpc_client_base_test.py
@@ -25,13 +25,14 @@
 
 class FakeRpcClient(jsonrpc_client_base.JsonRpcClientBase):
     def __init__(self):
-        super(FakeRpcClient, self).__init__(app_name='FakeRpcClient',
-            ad=mock.Mock())
+        super(FakeRpcClient, self).__init__(
+            app_name='FakeRpcClient', ad=mock.Mock())
 
 
 class JsonRpcClientBaseTest(jsonrpc_client_test_base.JsonRpcClientTestBase):
     """Unit tests for mobly.controllers.android_device_lib.jsonrpc_client_base.
     """
+
     @mock.patch('socket.create_connection')
     def test_open_timeout_io_error(self, mock_create_connection):
         """Test socket timeout with io error
@@ -99,7 +100,7 @@
     def test_rpc_error_response(self, mock_create_connection):
         """Test rpc that is given an error response
 
-        Test that when an rpc recieves a reponse with an error will raised
+        Test that when an rpc receives a response with an error will raised
         an api error.
         """
         fake_file = self.setup_mock_socket_file(mock_create_connection)
@@ -116,7 +117,7 @@
     def test_rpc_callback_response(self, mock_create_connection):
         """Test rpc that is given a callback response.
 
-        Test that when an rpc recieves a callback reponse, a callback object is
+        Test that when an rpc receives a callback response, a callback object is
         created correctly.
         """
         fake_file = self.setup_mock_socket_file(mock_create_connection)
@@ -152,7 +153,7 @@
 
     @mock.patch('socket.create_connection')
     def test_rpc_no_response(self, mock_create_connection):
-        """Test rpc that does not get a reponse
+        """Test rpc that does not get a response
 
         Test that when an rpc does not get a response it throws a protocol
         error.
diff --git a/tests/mobly/controllers/android_device_lib/snippet_client_test.py b/tests/mobly/controllers/android_device_lib/snippet_client_test.py
index 5968411..4f9e441 100755
--- a/tests/mobly/controllers/android_device_lib/snippet_client_test.py
+++ b/tests/mobly/controllers/android_device_lib/snippet_client_test.py
@@ -222,9 +222,9 @@
     @mock.patch('socket.create_connection')
     @mock.patch('mobly.controllers.android_device_lib.snippet_client.'
                 'SnippetClient.disconnect')
-    def test_snippet_stop_app_raises(self, mock_disconect,
+    def test_snippet_stop_app_raises(self, mock_disconnect,
                                      mock_create_connection):
-        mock_disconect.side_effect = Exception('ha')
+        mock_disconnect.side_effect = Exception('ha')
         adb_proxy = mock.MagicMock()
         adb_proxy.shell.return_value = b'OK (0 tests)'
         client = self._make_client(adb_proxy)
diff --git a/tests/mobly/logger_test.py b/tests/mobly/logger_test.py
index f1326f0..2adc08a 100755
--- a/tests/mobly/logger_test.py
+++ b/tests/mobly/logger_test.py
@@ -31,7 +31,7 @@
         self.assertTrue(
             logger.is_valid_logline_timestamp("06-21 17:44:42.336"))
 
-    def test_is_valid_logline_timestamp_when_wrong_lenght(self):
+    def test_is_valid_logline_timestamp_when_wrong_length(self):
         self.assertFalse(
             logger.is_valid_logline_timestamp("  06-21 17:44:42.336"))
diff --git a/mobly/base_instrumentation_test.py b/mobly/base_instrumentation_test.py
index 56b127a..efbc993 100644
--- a/mobly/base_instrumentation_test.py
+++ b/mobly/base_instrumentation_test.py
@@ -99,7 +99,7 @@
 class _InstrumentationStatusCodes(object):
     """A mapping of instrumentation status codes to test method results.
 
     When instrumentation runs, at various points ouput is created in a serias
     of blocks that terminate as follows:
 
     .. code-block:: none
@@ -171,7 +171,7 @@
         INSTRUMENTATION_RESULT:
 
     If something wrong happened during the instrumentation run such as an
-    application under test crash, the the line will appear similarly as thus:
+    application under test crash, the line will appear similarly as thus:
 
     .. code-block:: none
 
@@ -227,7 +227,7 @@
 class _InstrumentationBlockStates(Enum):
     """States used for determing what the parser is currently parsing.
 
-    The parse always starts and ends a block in the UKNOWN state, which is
+    The parse always starts and ends a block in the UNKNOWN state, which is
     used to indicate that either a method or a result block (matching the
     METHOD and RESULT states respectively) are valid follow ups, which means
     that parser should be checking for a structure prefix that indicates which
@@ -273,7 +273,7 @@
 
     Because these keys are poentially very long, constant string contatention
     is potentially inefficent. Instead, this class builds up a buffer to store
     the raw ouput until it is processed into an actual test result by the
     _InstrumentationBlockFormatter class.
 
     Additionally, this class also serves to store the parser state, which
@@ -396,7 +396,7 @@
         Args:
             structure_prefix: string, the structure prefix that was matched
                 and that needs to be removed.
             key_line: string, the raw instrumentation ouput line that contains
                 the key-value pair.
         """
         self._empty = False
@@ -447,7 +447,7 @@
             A new instrumentation block set to the new state, representing
             the start of parsing a new instrumentation test method.
             Alternatively, if the current instrumentation block represents the
-            start of parsing a new instrumentation block (state UKNOWN), then
+            start of parsing a new instrumentation block (state UNKNOWN), then
             this returns the current instrumentation block set to the now
             known parsing state.
         """
@@ -528,7 +528,7 @@
         return '#'.join(filter(None, full_name_parts))
 
     def _get_details(self):
         """Gets the ouput for the detail section of the TestResultRecord.
 
         Returns:
             A string to set for a TestResultRecord's details.
@@ -754,7 +754,7 @@
 
         Returns:
             The new instrumentation block to use for storing parsed
-            instrumentation ouput.
+            instrumentation output.
         """
         formatters = self._create_formatters(instrumentation_block, new_state)
         for formatter in formatters:
@@ -855,7 +855,7 @@
             return instrumentation_block
 
     def _parse_line(self, instrumentation_block, line):
-        """Parses an arbitary line from the instrumentation output based upon
+        """Parses an arbitrary line from the instrumentation output based upon
         the current parser state.
 
         Args:
@@ -99,7 +99,7 @@
     """A mapping of instrumentation status codes to test method results.
 
-    When instrumentation runs, at various points ouput is created in a serias
+    When instrumentation runs, at various points output is created in a series
     of blocks that terminate as follows:
 
@@ -273,7 +273,7 @@
     Because these keys are poentially very long, constant string contatention
     is potentially inefficent. Instead, this class builds up a buffer to store
-    the raw ouput until it is processed into an actual test result by the
+    the raw output until it is processed into an actual test result by the
     _InstrumentationBlockFormatter class.
 
@@ -396,7 +396,7 @@
             structure_prefix: string, the structure prefix that was matched
                 and that needs to be removed.
-            key_line: string, the raw instrumentation ouput line that contains
+            key_line: string, the raw instrumentation output line that contains
                 the key-value pair.
         """
@@ -528,7 +528,7 @@
 
     def _get_details(self):
-        """Gets the ouput for the detail section of the TestResultRecord.
+        """Gets the output for the detail section of the TestResultRecord.
 
         Returns: